<?php

  namespace FiloBlu\Storelocator\Model\Plugin\Rma;

  use Magento\Store\Model\Store;
  use Magento\Sales\Model\Order\Address;
  use Magento\Framework\Api\AttributeValueFactory;
  use Magento\Rma\Api\RmaAttributesManagementInterface;


  class Rma
  {
    protected $_helper;
    protected $_quoteFactory;
    protected $_orderRepository;
    protected $_storesFactory;
    protected $_rmaHelper;
    protected $_transportBuilder;
    protected $_storeManager;
    protected $_inlineTranslation;
    protected $_paymentHelper;
    protected $_addressRenderer;

    public function __construct(
      \FiloBlu\Storelocator\Helper\Data $helper,
      \Magento\Quote\Model\QuoteFactory $quoteFactory,
      \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
      \FiloBlu\Storelocator\Model\StoresFactory $storesFactory,
      \Magento\Rma\Helper\Data $rmaHelper,
      \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder,
      \Magento\Store\Model\StoreManagerInterface $storeManager,
      \Magento\Framework\Translate\Inline\StateInterface $inlineTranslation,
      \Magento\Payment\Helper\Data $paymentHelper,
      \Magento\Sales\Model\Order\Address\Renderer $addressRenderer
    ) {
      $this->_helper = $helper;
      $this->_quoteFactory = $quoteFactory;
      $this->_orderRepository = $orderRepository;
      $this->_storesFactory = $storesFactory;
      $this->_rmaHelper = $rmaHelper;
      $this->_transportBuilder = $transportBuilder;
      $this->_storeManager = $storeManager;
      $this->_inlineTranslation = $inlineTranslation;
      $this->_paymentHelper = $paymentHelper;
      $this->_addressRenderer = $addressRenderer;
    }


    public function afterSave($interceptor, $rma) {
      if ($this->_helper->getConfig("carriers/pickupinstore/active")) {

        if((int)$rma->getData('return_to_store_id') > 0 && $rma->getStatus() == 'pending') {
          try {
            if($rma->getData('return_to_store_received_date') == null) {
              $this->sendMail($rma);
            }
          } catch (\Exception $ex) {

          }
        }
      }

      return $rma;

    }

    protected function sendMail($rma)
    {
      if(!$this->_helper->getConfig("carriers/pickupinstore/pickrma_email_to_store_enabled")) {
        return;
      }

      $store_id = $rma->getData('return_to_store_id');
      $shop = $this->getStoreDetails($store_id);
      if($shop && $shop->getEmail() != '') {
        $this->_inlineTranslation->suspend();

        try {
          $returnAddress = $this->_rmaHelper->getReturnAddress('html', [], $store_id);
          $order = $rma->getOrder();

          $transport = $this->_transportBuilder
            ->setTemplateIdentifier($this->_helper->getConfig("carriers/pickupinstore/pickrma_email_to_store_template"))
            ->setTemplateOptions(['area' => \Magento\Framework\App\Area::AREA_FRONTEND, 'store' => $this->_storeManager->getStore()->getStoreId()])
            ->setTemplateVars(
              [
                'rma' => $rma,
                'order' => $rma->getOrder(),
                'shop' => $shop,
                'store' => $rma->getOrder()->getStore(),
                'billing' => $order->getBillingAddress(),
                'payment_html' => $this->_paymentHelper->getInfoBlockHtml(
                  $order->getPayment(),
                  $this->_storeManager->getStore()->getId()
                ),
                'return_address' => $returnAddress,
                'item_collection' => $rma->getItemsForDisplay(),
                'formattedShippingAddress' => $this->_addressRenderer->format(
                  $order->getShippingAddress(),
                  'html'
                ),
                'formattedBillingAddress' => $this->_addressRenderer->format(
                  $order->getBillingAddress(),
                  'html'
                ),
              ]
            )
            ->setFrom($this->_helper->getConfig("carriers/pickupinstore/pickrma_sender_email_to_store_identity"))
            ->addTo($rma->getReturnToStoreEmail())
            ->getTransport();
          $transport->sendMessage();

          $this->_inlineTranslation->resume();
        } catch(\Exception $e) {
          $this->_inlineTranslation->resume();
        }
      }
    }

    protected function getStoreDetails($store_id) {
      if((int)$store_id > 0) {
        $shop = $this->_storesFactory->create()->load($store_id);

        return $shop;
      }

      return false;
    }
  }
